@@ -17,7 +17,7 @@ has 'force_drop_table' => (
     default=>0,
 );
 
-has 'keep_db' => (
+has [qw/keep_db tdbic_debug/] => (
     traits=>['ENV'],
     is=>'ro',
     isa=>'Bool',
@@ -60,6 +60,17 @@ has 'connect_info' => (
     lazy_build => 1,
 );
 
+has 'connect_opts' => (
+    is => 'ro',
+    isa => 'HashRef',
+);
+
+has 'connect_info_with_opts' => (
+    is => 'ro',
+    isa => 'HashRef',
+    lazy_build => 1,
+);
+
 has 'fixture_class' => (
     traits => ['ENV'],
     is => 'ro',
@@ -99,7 +110,7 @@ sub get_fixture_sets {
 sub _build_schema {
     my $self = shift @_;
     my $schema_class = $self->schema_class;
-    my $connect_info = $self->connect_info;
+    my $connect_info = $self->connect_info_with_opts;
 
     return unless $schema_class;
 
@@ -117,6 +128,11 @@ sub _build_connect_info {
     }
 }
 
+sub _build_connect_info_with_opts{
+    my ($self) = @_;
+    return { %{$self->connect_info}, %{$self->connect_opts || {}} };
+}
+
 sub _build_fixture_command {
     my $self = shift @_;
     return $self->fixture_class->new(schema_manager=>$self);
@@ -222,7 +238,7 @@ sub install_fixtures {
         or (ref $args[0] eq 'HASH' && $args[0]->{command}) ) {
         my $arg = ref $args[0] ?  $args[0]->{command} : $args[0];
         my $fixture_class = to_FixtureClass($arg);
-        $self->builder->diag("Override default FixtureClass '".$self->fixture_class."' with $fixture_class");
+        $self->builder->diag("Override default FixtureClass '".$self->fixture_class."' with $fixture_class") if $self->tdbic_debug;
         $fixture_command = $fixture_class->new(schema_manager=>$self);
         shift(@args);
     }
